# MIGEO: 
# Modelagem e Inversão Geofísica Eletromagnética
![miGEO Image Logo](https://github.com/projetoemBR/migeo-master/blob/master/migeo-logo2.png)

MIGEO é um pacote python de modelagem e inversão geofísica eletromagnética por volumes finitos baseada em códigos open-source.  

# Geração de Malha
O gerador de malha em volumes finitos utilizado é do pacote open-source *discretize* que possui as seguintes malhas disponíveis:

  - Malha Tensor
  - Malha Octree

# Modelagem direta: MT

  - Volumes Finitos
  - Modelagem 1D, 2D e 3D
  - Disponível na malha tipo Tensor e Octree
  - Isotrópica (anisotropia em andamento)

# Modelagem direta: MCSEM

  - Volumes Finitos
  - Modelagem 1D, 2D e 3D
  - Disponível na malha tipo Tensor
  - Anisotrópica

# Inversão dos campos MT e MCSEM
  - Em andamento

# Instalação
Recomendada a criação de um ambiente virtual conda com python > v3.7 para fazer a instalação via pip.
```sh
$ pip install migeo
```



License
----

MIT

[//]: # (These are reference links used in the body of this note and get stripped out when the markdown processor does its job. There is no need to format nicely because it shouldn't be seen. Thanks SO - http://stackoverflow.com/questions/4823468/store-comments-in-markdown-syntax)


   [dill]: <https://github.com/joemccann/dillinger>
   [git-repo-url]: <https://github.com/joemccann/dillinger.git>
   [john gruber]: <http://daringfireball.net>
   [df1]: <http://daringfireball.net/projects/markdown/>
   [markdown-it]: <https://github.com/markdown-it/markdown-it>
   [Ace Editor]: <http://ace.ajax.org>
   [node.js]: <http://nodejs.org>
   [Twitter Bootstrap]: <http://twitter.github.com/bootstrap/>
   [jQuery]: <http://jquery.com>
   [@tjholowaychuk]: <http://twitter.com/tjholowaychuk>
   [express]: <http://expressjs.com>
   [AngularJS]: <http://angularjs.org>
   [Gulp]: <http://gulpjs.com>

   [PlDb]: <https://github.com/joemccann/dillinger/tree/master/plugins/dropbox/README.md>
   [PlGh]: <https://github.com/joemccann/dillinger/tree/master/plugins/github/README.md>
   [PlGd]: <https://github.com/joemccann/dillinger/tree/master/plugins/googledrive/README.md>
   [PlOd]: <https://github.com/joemccann/dillinger/tree/master/plugins/onedrive/README.md>
   [PlMe]: <https://github.com/joemccann/dillinger/tree/master/plugins/medium/README.md>
   [PlGa]: <https://github.com/RahulHP/dillinger/blob/master/plugins/googleanalytics/README.md>

